@@ -22,7 +22,7 @@
 
 #define QT_FEATURE_gstreamer_gl_egl 1
 
-#define QT_FEATURE_gstreamer_gl_x11 -1
+#define QT_FEATURE_gstreamer_gl_x11 1
 
 #define QT_FEATURE_gpu_vivante -1
 
@@ -38,8 +38,6 @@
 
 #define QT_FEATURE_pulseaudio 1
 
-#define QT_FEATURE_wmsdk -1
-
 #define QT_FEATURE_opensles -1
 
 #define QT_FEATURE_wasm -1
@@ -50,3 +48,5 @@
 
 #define QT_FEATURE_spatialaudio_quick3d 1
 
+#define QT_FEATURE_ffmpeg_stubs -1
+
